@@ -8,55 +8,43 @@ sub register_commands {
                       label    => 'Run',
                       priority => 200,
                       },
-        next     => { sub      => \&next,
+        next     => { sub      => sub { $_[0]->ebug->next },
                       key      => 'n',
                       menu     => 'run',
                       label    => 'Next',
                       priority => 20,
                       },
-        step     => { sub      => \&step,
+        step     => { sub      => sub { $_[0]->ebug->step },
                       key      => 's',
                       menu     => 'run',
                       label    => 'Step',
                       priority => 20,
                       },
-        return   => { sub      => \&return,
+        return   => { sub      => sub { $_[0]->ebug->return },
                       key      => 'u',
                       menu     => 'run',
                       label    => 'Return',
                       priority => 20,
                       },
-        run      => { sub      => \&run,
+        run      => { sub      => sub { $_[0]->ebug->run },
                       key      => 'r',
                       menu     => 'run',
                       label    => 'Run',
                       priority => 10,
                       },
+        restart  => { sub      => \&restart,
+                      menu     => 'run',
+                      label    => 'Restart',
+                      priority => 30,
+                      },
         );
 }
 
-sub next {
+sub restart {
     my( $wx ) = @_;
 
-    $wx->ebug->next;
-}
-
-sub step {
-    my( $wx ) = @_;
-
-    $wx->ebug->step;
-}
-
-sub run {
-    my( $wx ) = @_;
-
-    $wx->ebug->run;
-}
-
-sub return {
-    my( $wx ) = @_;
-
-    $wx->ebug->return;
+    # FIXME save and restore program state
+    $wx->ebug->load_program;
 }
 
 1;
