@@ -14,9 +14,15 @@ sub register_commands {
                        label    => 'Help',
                        priority => 10000,
                        },
-        quit      => { sub   => \&quit,
-                       menu  => 'file',
-                       label => 'Exit',
+        load_file => { sub      => \&load_file,
+                       menu     => 'file',
+                       label    => 'Load file',
+                       priority => 10,
+                       },
+        quit      => { sub      => \&quit,
+                       menu     => 'file',
+                       label    => 'Exit',
+                       priority => 100,
                        },
         about     => { sub   => \&about,
                        menu  => 'help',
@@ -39,4 +45,13 @@ sub about {
                     "About wxebug", wxOK, $wx );
 }
 
+sub load_file {
+    my( $wx ) = @_;
+    # FIXME better file selector, add arguments
+    my $file = Wx::FileSelector( "Select a Perl file" );
+    if( defined $file ) {
+        $wx->ebug->load_program( [ $file ] );
+    }
+}
+
 1;
