@@ -1,24 +1,21 @@
 package Devel::ebug::Wx::Command::Views;
 
-use Module::Pluggable
-      sub_name    => 'views',
-      search_path => 'Devel::ebug::Wx::View',
-      require     => 1,
-      except      => qr/::Base$|::View::Code::/;
+use strict;
 
 sub register_commands {
-    my( $class ) = @_;
+    my( $class, $wxebug ) = @_;
     my @commands;
 
-    foreach my $view ( $class->views ) {
+    foreach my $view ( $wxebug->view_manager_service->views ) {
         my $cmd = sub {
             my( $wx ) = @_;
 
             my $instance = $view->new( $wx, $wx );
-            $wx->manager->AddPane
-              ( $instance, $wx->pane_info->Name( $view->tag )->Float
-                ->Caption( $view->description ) );
-            $wx->manager->Update;
+            $wxebug->view_manager_service->create_pane_and_update
+              ( $instance, { name    => $view->tag,
+                             float   => 1,
+                             caption => $view->description,
+                             } );
         };
         push @commands, 'show_' . $view->tag,
              { sub      => $cmd,
