@@ -8,6 +8,12 @@ __PACKAGE__->mk_accessors( qw(wxebug _has_destroy _subscribed) );
 # not yet in wxPerl
 sub EVT_DESTROY($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_DESTROY, $_[2] ) }
 
+sub register_view {
+    my( $self ) = @_;
+
+    $self->wxebug->view_manager_service->register_view( $self );
+}
+
 sub subscribe_ebug {
     my( $self, $event, $handler ) = @_;
 
@@ -24,6 +30,7 @@ sub subscribe_ebug {
 sub _on_destroy {
     my( $self ) = @_;
     $self->ebug->delete_subscriber( @$_ ) foreach @{$self->_subscribed};
+    $self->wxebug->view_manager_service->unregister_view( $self );
     $self->_subscribed( undef );
 }
 
